"use strict";(self.webpackChunk_dagster_io_dagit_app=self.webpackChunk_dagster_io_dagit_app||[]).push([[713],{66042:function(e,t,r){r.r(t),r.d(t,{FallthroughRoot:function(){return p}});var n=r(79080),o=r(78193),i=r(8192),s=r(92761),a=r(63167),c=r(35936),l=function(){var e=(0,i.TH)(),t="".concat(e.pathname).concat(e.search);return(0,c.jsx)(i.l_,{to:"/instance".concat(t)})},p=function(){return(0,c.jsxs)(i.rs,{children:[(0,c.jsx)(i.AW,{path:["/runs/(.*)?","/assets/(.*)?","/scheduler"],children:(0,c.jsx)(l,{})}),(0,c.jsx)(i.AW,{path:"/home",children:(0,c.jsx)(d,{})}),(0,c.jsx)(i.AW,{path:"*",children:(0,c.jsx)(d,{})})]})},d=function(){var e=o.useContext(s.C5),t=e.allRepos,r=e.loading,l=e.locationEntries;if(r)return(0,c.jsx)(n.xu,{flex:{direction:"row",justifyContent:"center"},style:{paddingTop:"100px"},children:(0,c.jsxs)(n.xu,{flex:{direction:"row",alignItems:"center",gap:16},children:[(0,c.jsx)(n.$j,{purpose:"section"}),(0,c.jsx)("div",{style:{color:n.ow.Gray600},children:"Loading workspace\u2026"})]})});if(l.length&&0===t.length)return(0,c.jsx)(i.l_,{to:"/workspace"});var p=t.filter((function(e){return e.repository.pipelines.length>0}));if(1===p.length){var d=p[0],u=d.repository.pipelines[0];return(0,c.jsx)(i.l_,{to:(0,a.jT)({repoName:d.repository.name,repoLocation:d.repositoryLocation.name,pipelineName:u.name,isJob:u.isJob})})}if(p.length>1)return(0,c.jsx)(i.l_,{to:"/instance"});var h=t[0];return(0,c.jsx)(n.xu,{padding:{vertical:64},children:(0,c.jsx)(n.tR,{icon:"no-results",title:h?"No pipelines or jobs":"No repositories",description:h?"Your repository is loaded but no pipelines or jobs were found.":"Add a repository to get started.",action:(0,c.jsx)(n.fr,{href:"https://docs.dagster.io/getting-started",children:"View documentation"})})})};t.default=p}}]);
//# sourceMappingURL=713.3121b256.chunk.js.map