"use strict";(self.webpackChunk_dagster_io_dagit_app=self.webpackChunk_dagster_io_dagit_app||[]).push([[32],{5032:function(e,t,n){n.r(t),n.d(t,{default:function(){return k}});var o=n(59019),i=n(19065),r=n(79080),s=n(78193),c=n(67099),a=n(72691),u=n(58203),f=n.n(u),l=n(68409),d=n(96640),v=n(35936),g=function(e){var t=Math.abs(e);return"".concat(e<0?"+":"-").concat(Math.floor(t/60),":").concat(t%60<10?"0":"").concat(t%60)},x=f().tz.names().map((function(e){var t,n=(null===(t=f().tz.zone(e))||void 0===t?void 0:t.utcOffset(Date.now()))||0;return{offsetLabel:"".concat(g(n)),offset:n,key:e}})).sort((function(e,t){return e.offset-t.offset})),h=["UTC","US/Pacific","US/Mountain","US/Central","US/Eastern"],m=[{key:"Automatic",offsetLabel:function(){var e;return"".concat((0,d.AM)()," ").concat(g((null===(e=f().tz.zone((0,d.cw)()))||void 0===e?void 0:e.utcOffset(Date.now()))||0))}(),offset:0},{key:"divider-1",offsetLabel:"",offset:0}].concat((0,o.Z)(x.filter((function(e){return h.includes(e.key)}))),[{key:"divider-2",offsetLabel:"",offset:0}],(0,o.Z)(x.filter((function(e){return!h.includes(e.key)})))),p=function(e){var t=e.trigger,n=s.useContext(l.j),o=(0,i.Z)(n,2),c=o[0],a=o[1];return(0,v.jsx)(r.If,{popoverProps:{position:"bottom-left",modifiers:{offset:{enabled:!0,offset:"-12px, 8px"}}},activeItem:m.find((function(e){return e.key===c})),inputProps:{style:{width:"300px"}},items:m,itemPredicate:function(e,t){return t.key.toLowerCase().includes(e.toLowerCase())},itemRenderer:function(e,t){return e.key.startsWith("divider")?(0,v.jsx)(r.vo,{},e.key):(0,v.jsx)(r.z3,{active:t.modifiers.active,onClick:t.handleClick,label:e.offsetLabel,text:e.key},e.key)},itemListRenderer:function(e){var t=e.renderItem,n=e.filteredItems.map(t).filter(Boolean);return(0,v.jsx)(r.ab,{children:n})},noResults:(0,v.jsx)(r.z3,{disabled:!0,text:"No results."}),onItemSelect:function(e){return a(e.key)},children:t(c)})},k=function(){(0,c.j)("User settings");var e=s.useState((function(){return(0,a.BZ)()})),t=(0,i.Z)(e,2),n=t[0],u=t[1];s.useEffect((function(){(0,a.zt)(n)}));var f=s.useCallback((function(e){return(0,v.jsx)(r.ZP,{children:"Automatic"===e?(0,d.aA)():e})}),[]);return(0,v.jsxs)("div",{style:{height:"100vh",overflowY:"auto"},children:[(0,v.jsx)(r.mr,{title:(0,v.jsx)(r.X6,{children:"User settings"})}),(0,v.jsxs)(r.xu,{padding:{vertical:16,horizontal:24},children:[(0,v.jsx)(r.xu,{padding:{bottom:8},children:(0,v.jsx)(r.pm,{children:"Preferences"})}),(0,v.jsx)(r.nZ,{rows:[{key:"Timezone",value:(0,v.jsx)(p,{trigger:f})}]})]}),(0,v.jsxs)(r.xu,{padding:{vertical:16,horizontal:24},border:{side:"top",width:1,color:r.ow.KeylineGray},children:[(0,v.jsx)(r.xu,{padding:{bottom:8},children:(0,v.jsx)(r.pm,{children:"Experimental features"})}),(0,v.jsx)(r.nZ,{rows:[{key:"Debug console logging",value:(0,v.jsx)(r.XZ,{format:"switch",checked:n.includes(a.TT.flagDebugConsoleLogging),onChange:function(){return e=a.TT.flagDebugConsoleLogging,u(n.includes(e)?n.filter((function(t){return t!==e})):[].concat((0,o.Z)(n),[e])),void window.location.reload();var e}})}]})]})]})}},67099:function(e,t,n){n.d(t,{j:function(){return i}});var o=n(78193),i=function(e){o.useEffect((function(){var t=document.title;return document.title=e,function(){document.title=t}}),[e])}}}]);
//# sourceMappingURL=32.45684bb9.chunk.js.map